@@ -456,8 +456,10 @@ class MultiHarmonicFitter(BaseFitter):
 
                     freq, power = ls.autopower(normalization='psd',
                                                samples_per_peak=2000,
-                                               minimum_frequency=max(1e-10,freq[power.argmax()]-5/self.t.ptp()),
-                                               maximum_frequency=freq[power.argmax()]+20/self.t.ptp())
+                                               minimum_frequency=max(minimum_frequency if minimum_frequency is not None else 1e-10,
+                                                                    freq[power.argmax()]-5/self.t.ptp()),
+                                               maximum_frequency=min(maximum_frequency if maximum_frequency is not None else np.inf,
+                                                                    freq[power.argmax()]+20/self.t.ptp()) )
 
                     # LS may return inf values
                     goodpts = np.isfinite(power)
@@ -1093,6 +1095,7 @@ class MultiFrequencyFitter(BaseFitter):
 
             #if np.nanmax(power) <= np.nanmean(power) + sigma*np.nanstd(power):
             if np.nanmax(power) / np.nanmean(power) < sigma:
+                warn('Reached the %.1f sigma limit' % sigma)
                 # s/n < sigma
                 break
 
@@ -1105,8 +1108,10 @@ class MultiFrequencyFitter(BaseFitter):
             with np.errstate(divide='ignore',invalid='ignore'):
                 freq, power = ls.autopower(normalization='psd',
                                            samples_per_peak=2000,
-                                           minimum_frequency=max(1e-10,freq[power.argmax()]-5/self.t.ptp()),
-                                           maximum_frequency=freq[power.argmax()]+20/self.t.ptp())
+                                           minimum_frequency=max(minimum_frequency if minimum_frequency is not None else 1e-10,
+                                                                freq[power.argmax()]-5/self.t.ptp()),
+                                           maximum_frequency=min(maximum_frequency if maximum_frequency is not None else np.inf,
+                                                                freq[power.argmax()]+20/self.t.ptp()) )
 
             # Convert LS power to amplitude
             power = np.sqrt(4*power/len(self.t))
@@ -1144,9 +1149,12 @@ class MultiFrequencyFitter(BaseFitter):
 
                 best_freq = pfit[1]
 
+                if np.allclose(best_freq ,0):
+                    raise ValueError("Found period is infinite. Skipping...")
+
             except (RuntimeError,ValueError) as err:
                 if i == 0:
-                    warn(err)
+                    warn(str(err))
 
                     self.pfit = self.perr = [np.nan]*(3+1)
                     return self.pfit, self.perr
@@ -1396,8 +1404,8 @@ class MultiFrequencyFitter(BaseFitter):
 
             warn('Something went wrong! Returning errors from pre-whitening steps.')
 
-            self.pfit = np.array([self.freqs, *self.amps, *self.phases, self.zeropoints[0] ])
-            self.perr = np.array([self.freqserr, *self.ampserr, *self.phaseserr, self.zeropointerr[0] ])
+            self.pfit = np.array([*self.freqs, *self.amps, *self.phases, self.zeropoints[0] ])
+            self.perr = np.array([*self.freqserr, *self.ampserr, *self.phaseserr, self.zeropointerr[0] ])
             self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
             return self.pfit, self.perr
 
